@@ -7,7 +7,7 @@
  
     :Example:
  
-    >>> import hades.aero.Isentropic as Is
+    >>> import aerokit.aero.Isentropic as Is
     >>> Is.TiTs_Mach(1.)
     1.2
     >>> Is.TiTs_Mach(2., gamma=1.6)
@@ -20,7 +20,6 @@
  """
 
 import numpy as np
-import math
 import flowdyn.modelphy.base as mbase
 
 # ===============================================================
@@ -55,9 +54,13 @@ class base(mbase.model):
         self.shape       = [1, 1, 1]
         self.gamma       = gamma
         self.source      = source
+        self._vardict = { 'pressure': self.pressure, 'density': self.density,
+                          'velocity': self.velocity, 'mach': self.mach, 'enthalpy': self.enthalpy,
+                          'entropy': self.entropy, 'ptot': self.ptot, 'rttot': self.rttot, 'htot': self.htot }
         
     def cons2prim(self, qdata): # qdata[ieq][cell] :
         """
+        Primitives variables are rho, u, p
         >>> model().cons2prim([[5.], [10.], [20.]])
         True
         """
@@ -105,12 +108,16 @@ class base(mbase.model):
         gm1 = self.gamma-1.
         return self.pressure(qdata)*(1.+.5*gm1*self.mach(qdata)**2)**(self.gamma/gm1)
 
+    def rttot(self, qdata):
+        ec = 0.5*qdata[1]**2/qdata[0]
+        return ((qdata[2]-ec)*self.gamma + ec)/qdata[0]/self.gamma*(self.gamma-1.)
+
     def htot(self, qdata):
         ec = 0.5*qdata[1]**2/qdata[0]
         return ((qdata[2]-ec)*self.gamma + ec)/qdata[0]
 
     def numflux(self, name, pdataL, pdataR, dir=None):
-        if name==None: name='hllc'
+        if name is None: name='hllc'
         return (self._numfluxdict[name])(pdataL, pdataR, dir)
 
     def numflux_centeredflux(self, pdataL, pdataR, dir=None): # centered flux ; pL[ieq][face]
@@ -305,9 +312,7 @@ class euler1d(base):
     def __init__(self, gamma=1.4, source=None):
         base.__init__(self, gamma=gamma, source=source)
         self.shape       = [1, 1, 1]
-        self._vardict = { 'pressure': self.pressure, 'density': self.density,
-                          'velocity': self.velocity, 'mach': self.mach, 'enthalpy': self.enthalpy,
-                          'entropy': self.entropy, 'ptot': self.ptot, 'htot': self.htot }
+        self._vardict.update({ 'massflow': self.massflow })
         self._bcdict.update({'sym': self.bc_sym,
                          'insub': self.bc_insub,
                          'insup': self.bc_insup,
@@ -325,6 +330,9 @@ class euler1d(base):
         H  = c2/(self.gamma-1.) + .5*pdata[1]**2
         return pdata[0], pdata[1], pdata[1], c2, H
 
+    def massflow(self,qdata): # for 1D model only
+        return qdata[1].copy()
+
     def bc_sym(self, dir, data, param):
         "symmetry boundary condition, for inviscid equations, it is equivalent to a wall, do not need user parameters"
         return [ data[0], -data[1], data[2] ]
@@ -341,9 +349,10 @@ class euler1d(base):
         # expected parameters are 'ptot', 'rttot' and 'p'
         g   = self.gamma
         gmu = g-1.
+        p  = param['p']
         m2 = np.maximum(0., ((param['ptot']/param['p'])**(gmu/g)-1.)*2./gmu)
         rh = param['ptot']/param['rttot']/(1.+.5*gmu*m2)**(1./gmu)
-        return param
+        return [ rh, -dir*np.sqrt(g*m2*p/rh), p ] 
 
     def bc_outsub(self, dir, data, param):
         return [ data[0], data[1], param['p'] ] 
@@ -364,8 +373,14 @@ class nozzle(euler1d):
     attributes:
 
     """
-    def __init__(self, sectionlaw, gamma=1.4):
-        euler1d.__init__(self, gamma=gamma, source=[ self.src_mass, self.src_mom, self.src_energy ])
+    def __init__(self, sectionlaw, gamma=1.4, source=None):
+        nozsrc = [ self.src_mass, self.src_mom, self.src_energy ]
+        allsrc = nozsrc # init all sources to nozzle sources
+        if source: # additional sources ?
+            for i,isrc in enumerate(source):
+                if isrc:
+                    allsrc[i] = lambda x,q: isrc(x,q)+nozsrc[i](x,q)
+        euler1d.__init__(self, gamma=gamma, source=allsrc)
         self.sectionlaw = sectionlaw
  
     def initdisc(self, mesh):
@@ -374,6 +389,9 @@ class nozzle(euler1d):
                     (mesh.xf[1:mesh.ncell+1]-mesh.xf[0:mesh.ncell])
         return 
 
+    def massflow(self,qdata):
+        return qdata[1]*self.sectionlaw(mesh.centers())
+
     def src_mass(self, x, qdata):
         return -self.geomterm * qdata[1]
 
@@ -394,10 +412,8 @@ class euler2d(base):
     def __init__(self, gamma=1.4, source=None):
         base.__init__(self, gamma=gamma, source=source)
         self.shape       = [1, 2, 1]
-        self._vardict = { 'pressure': self.pressure, 'density': self.density,
-                          'velocity': self.velocity, 'velocity_x': self.velocity_x, 'velocity_y': self.velocity_y,
-                          'mach': self.mach, 'enthalpy': self.enthalpy,
-                          'entropy': self.entropy, 'ptot': self.ptot, 'htot': self.htot }
+        self._vardict.update({ 'velocity_x': self.velocity_x, 'velocity_y': self.velocity_y,
+                         })
         self._bcdict.update({ #'sym': self.bc_sym,
                         #  'insub': self.bc_insub,
                         #  'insup': self.bc_insup,
@@ -428,12 +444,8 @@ class euler2d(base):
         return rhoUmag/np.sqrt(self.gamma*((self.gamma-1.0)*(qdata[0]*qdata[2]-0.5*rhoUmag**2)))
 
     def numflux_centeredflux(self, pdataL, pdataR, dir): # centered flux ; pL[ieq][face]
-        gam  = self.gamma
-        gam1 = gam-1.
-
         rhoL, unL, VL, pL, HL, cL2 = self._derived_fromprim(pdataL, dir)
-        rhoR, unR, VR, pR, HR, cR2 = self._derived_fromprim(pdataR, dir)
-    
+        rhoR, unR, VR, pR, HR, cR2 = self._derived_fromprim(pdataR, dir)  
         # final flux
         Frho  = .5*( rhoL*unL + rhoR*unR )
         Frhou = .5*( (rhoL*unL)*VL + pL*dir + (rhoR*unR)*VR + pR*dir)
